---
title: <span class="badge object-type-scalar"></span> Pixels
---
# <span class="badge object-type-scalar"></span> Pixels

Pixels (px)

## Definition

```python
# Pixels (px)
Pixels: typing.Literal["pixel"] = "pixel"
```
